@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use version;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -141,6 +141,10 @@ __END__
 Module::CheckDep::Version - List prereqs that need a version bump for an
 author's distributions
 
+=for html
+<a href="http://travis-ci.org/stevieb9/module-checkdep-version"><img src="https://secure.travis-ci.org/stevieb9/module-checkdep-version.png"/>
+<a href='https://coveralls.io/github/stevieb9/module-checkdep-version?branch=master'><img src='https://coveralls.io/repos/stevieb9/module-checkdep-version/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
+
 =head1 SYNOPSIS
 
     use Module::CheckDep::Version qw(check_deps);
@@ -190,6 +194,10 @@ author's distributions
 
 =head1 DESCRIPTION
 
+See L</bin/checkdep> for a binary script that you can use directly instead of
+using this API. You can also run `perldoc checkdep` at the command line after
+installation to read its manual.
+
 This module retrieves all [http://cpan.org|CPAN] distributions for a single
 author, extracts out all of the dependencies for each distribution, then lists
 all dependencies that have updated versions so you're aware which prerequisite
